Returns the list of references associated to the reconstruction.
cite_crest(x, verbose = TRUE)A list of references to add if the data generated by crestr are published.
A crestObj produced by one of the crest,
crest.get_modern_data, crest.calibrate,
crest.reconstruct or loo functions.
A boolean to print non-essential comments on the terminal
(default TRUE).